Module: BlastRadius::ActiveRecordExtension::InstanceMethods
- Defined in:
- lib/blast_radius/active_record_extension.rb
Instance Method Summary collapse
-
#blast_radius_dry_run(options = {}) ⇒ Hash
Perform a dry run to see what would be deleted.
-
#blast_radius_impact(options = {}) ⇒ Hash
Calculate the blast radius impact for this specific record.
Instance Method Details
#blast_radius_dry_run(options = {}) ⇒ Hash
Perform a dry run to see what would be deleted
56 57 58 59 |
# File 'lib/blast_radius/active_record_extension.rb', line 56 def blast_radius_dry_run( = {}) calculator = BlastRadius::ImpactCalculator.new calculator.dry_run(self, ) end |
#blast_radius_impact(options = {}) ⇒ Hash
Calculate the blast radius impact for this specific record
47 48 49 50 |
# File 'lib/blast_radius/active_record_extension.rb', line 47 def blast_radius_impact( = {}) calculator = BlastRadius::ImpactCalculator.new calculator.calculate(self, ) end |